using System;
using System.Collections.Generic;
using Jypeli;
using Jypeli.Assets;
using Jypeli.Controls;
using Jypeli.Widgets;

namespace Kolikkogoblin;
/// @author  Janne Yli-Tainio
/// @version 18.10.2023
/// <summary>
/// 
/// </summary>
public class Kolikkogoblin : PhysicsGame
{
    private static readonly String[] lines = {
                  "                        ",
                  "                        ",
                  "                        ",
                  "                        ",
                  "                        ",
                  "                   X    ",
                  "                 X      ",
                  "               X        ",
                  "   *                    ",
                  "   XXX                  ",
                  "      w w     g         ",
                  };
    
    private static readonly int tileWidth = 800 / lines[0].Length;
    private static readonly int tileHeight = 480 / lines.Length;

    public override void Begin()
    {
        //Gravity = new Vector(0, -500);

        Level.Background.CreateGradient(Color.Black, Color.Gray);
        TileMap tiles = TileMap.FromStringArray(lines);

        tiles.SetTileMethod('X', LuoPalikka, Color.Wheat);
        tiles.SetTileMethod('*', LuoKolikko, Color.Yellow);
        tiles.SetTileMethod('g', LuoGoblin, Color.Green);
        tiles.SetTileMethod('w', LuoPiikkeja, Color.DarkGray);

        tiles.Execute(tileWidth, tileHeight);

        Level.CreateBorders();
        Camera.ZoomToLevel();
        
        
        PhoneBackButton.Listen(ConfirmExit, "Lopeta peli");
        Keyboard.Listen(Key.Escape, ButtonState.Pressed, ConfirmExit, "Lopeta peli");
    }


    private void LuoPalikka(Vector paikka, double leveys, double korkeus, Color vari)
    {
        PhysicsObject palikka = new PhysicsObject(leveys , korkeus);
        palikka.Position = paikka;
        palikka.Color = vari;
        palikka.Tag = "rakenne";
        palikka.Image = LoadImage("palikka");
        Add(palikka);
    }

    private void LuoKolikko(Vector paikka, double leveys, double korkeus, Color vari)
    {
        PhysicsObject kolikko = new PhysicsObject(leveys * 1.5, leveys, Shape.Circle);
        kolikko.Position = paikka;
        kolikko.Color = vari;
        kolikko.Tag = "kolikko";
        kolikko.Image = LoadImage("kolikko");
        Add(kolikko);
    }
    
    private void LuoGoblin(Vector paikka, double leveys, double korkeus, Color vari)
    { 
        PlatformCharacter goblin = new PlatformCharacter(leveys*2 , korkeus *2);
        goblin.Position = paikka;
        goblin.Color = vari;
        goblin.Image = LoadImage("goblin1");
        Add(goblin);
        
        Keyboard.Listen(Key.Left, ButtonState.Down, LiikutaPelaajaa, null, new Vector(-20000, 0));
        Keyboard.Listen(Key.Right, ButtonState.Down, LiikutaPelaajaa, null, new Vector(20000, 0));
        Keyboard.Listen(Key.Up, ButtonState.Down, LiikutaPelaajaa, null, new Vector(0, 7000));
        Keyboard.Listen(Key.Down, ButtonState.Down, LiikutaPelaajaa, null, new Vector(0, -7000));
        
        void LiikutaPelaajaa(Vector vektori)
        {
            goblin.Push(vektori);
        }
    }
    
    private void LuoPiikkeja(Vector paikka, double leveys, double korkeus, Color vari)
        {
            PhysicsObject piikkeja = new PhysicsObject(100, 30);
            piikkeja.IgnoresCollisionResponse = true;
            piikkeja.Position = paikka;
            Image piikkienkuva = LoadImage("piikkeja");
            piikkeja.Image = piikkienkuva;
            piikkeja.Tag = "piikkeja";
            Add(piikkeja);

        } 
}
